@@ -397,8 +397,7 @@ class Spicer(HasTraits):
     def snormal(self):
         if not self.spoint_set:
             raise SPointNotSetError
-        a, b, c = self.radii
-        return spice.surfnm(a, b, c, self.spoint)
+        return spice.surfnm(*self.radii, self.spoint)
 
     @property
     def coords(self):
@@ -415,7 +414,7 @@ class Spicer(HasTraits):
     def _get_flux(self, vector):
         diff_angle = spice.vsep(vector, self.sun_direction)
         if (self.illum_angles.dsolar > 90 * u.deg) or (np.degrees(diff_angle) > 90):
-            return 0
+            return 0 * u.W / (u.m * u.m)
         else:
             return (
                 self.solar_constant
@@ -514,6 +513,53 @@ class Spicer(HasTraits):
         else:
             return np.array(energies)
 
+    @property
+    def subsolar(self):
+        # normalize surface point vector:
+        uuB = spice.vhat(self.center_to_sun)
+
+        # receive subsolar point in IAU_MARS rectangular coords
+        # the *self.radii unpacks the Radii object into 3 arguments.
+        v_subsolar = spice.surfpt((0, 0, 0), uuB, *self.radii)
+
+        return v_subsolar
+
+    def point_towards_sun(self, pixel_res=0.5):
+        """
+        Compute the solar azimuth.
+
+        Pixel resolution is required to stay within one pixel of the origin
+        point
+        """
+        # Check if surface point spoint was set
+        if not self.spoint_set:
+            raise SPointNotSetError
+        # Get the difference vector poB=subsolar-origin with its tail at origin
+        # and its head at the subsolar point
+        poB = spice.vsub(self.subsolar, self.spoint)
+
+        # get pixel scale in km/pixel and then divide by 2 to insure to stay
+        # within a pixel of the origin point
+        scale = (pixel_res / 1000.0) / 2.0
+
+        # the difference vector cuts through the body,
+        # we need the tangent vector
+        # to the surface at the origin point. vperp receives the perpendicular
+        # component of the poB towards the spoint vector
+        hpoB = spice.vperp(poB, self.spoint)
+        # unitize the tangent vector and then scale it to within a pixel of the
+        # origin point
+        upoB = spice.vhat(hpoB)
+        spoB = spice.vscl(scale, upoB)
+
+        # Compute the new point in body fixed. This point will be within a
+        # pixel of the origin but in the same direction as the requested la/lon
+        # of the point of interest, i.e. the subsolar point
+        nB = spice.vadd(self.spoint, spoB)
+
+        coords = SurfaceCoords.fromtuple(spice.reclat(nB))
+        return coords.dlon, coords.dlat
+
 
 class MarsSpicer(Spicer):
     target = "MARS"
